@@ -4,12 +4,12 @@
 Database of DNA sequences.
 """
 
-__version__ = '0.24.0'
+__version__ = '0.25.0'
 
 from .config import *
 from .errors import *
 from .model import *
-from .appcli import *
+from .byoc import *
 from .fields import *
 from .group_by import *
 from .utils import *
